# -------------------------------------------------------------------------------------------
#
# How to build for normal kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-8.1.15.el5' xfs.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-8.1.15.el5' xfs.spec
#
# How to build for normal kernel and XEN kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-8.1.15.el5' --define 'buildxen 1' xfs.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-8.1.15.el5' --define 'buildxen 1' xfs.spec
#
# How to build for normal kernel and PAE kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-8.1.15.el5' --define 'buildPAE 1' xfs.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-8.1.15.el5' --define 'buildPAE 1' xfs.spec
#
# How to build for all kernel (normal, xen, PAE)
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-8.1.15.el5' --define 'buildall 1' xfs.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-8.1.15.el5' --define 'buildall 1' xfs.spec
#
#
# How to build for the running kernel:
#
#  rpmbuild -ba --target i686   xfs.spec
#  rpmbuild -ba --target x86_64 xfs.spec
#
# -------------------------------------------------------------------------------------------

%{!?buildxen:%define buildxen 0}
%{!?buildPAE:%define buildPAE 0}

%{?buildall:%define buildxen 1}
%{?buildall:%define buildPAE 1}

%ifarch x86_64
%define buildPAE 0
%endif

%{?!kernel:%define kernel %(rpm -q kernel-devel | tail -1 | sed -e 's|kernel-devel-||')}

%define kversion %(echo "%{kernel}" | sed -e 's|-.*||')
%define krelease %(echo "%{kernel}" | sed -e 's|.*-||')

%define kernel_src_path %{_usrsrc}/kernels/%{kernel}-%{_target_cpu}
%define kernel_xen_src_path %{_usrsrc}/kernels/%{kernel}-xen-%{_target_cpu}
%define kernel_PAE_src_path %{_usrsrc}/kernels/%{kernel}-PAE-%{_target_cpu}

%define kernel_moduledir /lib/modules/%{kernel}
%define kernel_xen_moduledir /lib/modules/%{kernel}xen
%define kernel_PAE_moduledir /lib/modules/%{kernel}PAE

%define pkg_name xfs
%define kmdl_name kernel-module-%{pkg_name}-%{kernel}

# -------------------------------------------------------------------------------------------

Summary: 	The XFS(tm) Filesystem from Silicon Graphics, Inc.
Name: 		%{pkg_name}
Version: 	0.4
Release: 	1%{?dist}
Epoch: 		0
Packager: 	Urs Beyerle <urs.beyerle@psi.ch>
License: 	GPL
URL:            http://oss.sgi.com/projects/xfs
Group: 		System Environment/Kernel
Source0: 	%{pkg_name}.tar.bz2
Source1: 	config.xfs
# Allow the code to build as an out-of-tree module
Patch0:		xfs-ootbuild.patch

BuildRoot: 	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} )
Requires:       kernel-module-%{pkg_name} >= %{version}-%{release}
BuildRequires: 	kernel-devel = %{kernel}
%if %{buildxen}
BuildRequires: 	kernel-xen-devel = %{kernel}
%endif
%if %{buildPAE}
BuildRequires: 	kernel-PAE-devel = %{kernel}
%endif

%description
The XFS(tm) Filesystem from Silicon Graphics, Inc.
XFS is a highly scalable, high-performance journaling filesystem that provides 
rapid recovery from system crashes.

Kernel modules for %{name} are in kernel-module-%{pkg_name} rpms.

%package -n 	%{kmdl_name}
Summary:        Kernel modules for %{name}.
Group:          System Environment/Kernel
License:        GPL
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
# Requires:       %{pkg_name}

%description -n %{kmdl_name}
Kernel modules for %{name}.

The XFS(tm) Filesystem from Silicon Graphics, Inc.
XFS is a highly scalable, high-performance journaling filesystem that provides 
rapid recovery from system crashes.


%if %{buildxen}
%package -n 	%{kmdl_name}xen
Summary: 	Xen kernel modules for %{name}.
Group: 		System Environment/Kernel
License: 	GPL
Provides:	kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
# Requires:	%{pkg_name}

%description -n %{kmdl_name}xen
XEN kernel modules for %{name}.

The XFS(tm) Filesystem from Silicon Graphics, Inc.
XFS is a highly scalable, high-performance journaling filesystem that provides 
rapid recovery from system crashes.
%endif

%if %{buildPAE}
%package -n 	%{kmdl_name}PAE
Summary: 	PAE kernel modules for %{name}.
Group: 		System Environment/Kernel
License: 	GPL
Provides:	kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
# Requires:	%{pkg_name}

%description -n %{kmdl_name}PAE
PAE kernel modules for %{name}.

The XFS(tm) Filesystem from Silicon Graphics, Inc.
XFS is a highly scalable, high-performance journaling filesystem that provides 
rapid recovery from system crashes.
%endif

%prep
%setup -q -c -T -a 0
pushd %{pkg_name}
cp %{SOURCE1} .
%patch0 -p1

%define 	kernel_module_dir	kernel/fs/xfs


%build

echo -e "\nDriver version: %{version}\nKernel version: %{kernel}\n"
cd %{pkg_name}

make TOPDIR=%{kernel_src_path} clean
make TOPDIR=%{kernel_src_path} modules

INST_MODLIB=${RPM_BUILD_ROOT}/lib/modules/%{kernel}/%{kernel_module_dir}
mkdir -p ${INST_MODLIB}
cp *.ko ${INST_MODLIB}/


### XEN kernel
%if %{buildxen}

make TOPDIR=%{kernel_src_path} clean
make TOPDIR=%{kernel_src_path} modules

INST_MODLIB=${RPM_BUILD_ROOT}/lib/modules/%{kernel}xen/%{kernel_module_dir}
mkdir -p ${INST_MODLIB}
cp *.ko ${INST_MODLIB}/

%endif


### PAE kernel
%if %{buildPAE}

make TOPDIR=%{kernel_src_path} clean
make TOPDIR=%{kernel_src_path} modules

INST_MODLIB=${RPM_BUILD_ROOT}/lib/modules/%{kernel}PAE/%{kernel_module_dir}
mkdir -p ${INST_MODLIB}
cp *.ko ${INST_MODLIB}/

%endif


%install
echo

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%postun -n %{kmdl_name}
depmod -a %{kernel} >/dev/null 2>&1 || :	

%post -n %{kmdl_name}
depmod -a %{kernel} >/dev/null 2>&1 || :

%if %{buildxen}
%postun -n %{kmdl_name}xen
depmod -a %{kernel}xen >/dev/null 2>&1 || :

%post -n %{kmdl_name}xen
depmod -a %{kernel}xen >/dev/null 2>&1 || :
%endif

%if %{buildPAE}
%postun -n %{kmdl_name}PAE
depmod -a %{kernel}PAE >/dev/null 2>&1 || :

%post -n %{kmdl_name}PAE
depmod -a %{kernel}PAE >/dev/null 2>&1 || :
%endif


%files 
%defattr(-,root,root,-)

%files -n %{kmdl_name}
%defattr(744,root,root,-)
/lib/modules/%{kernel}/%{kernel_module_dir}

%if %{buildxen}
%files -n %{kmdl_name}xen
%defattr(744,root,root,-)
/lib/modules/%{kernel}xen/%{kernel_module_dir}
%endif

%if %{buildPAE}
%files -n %{kmdl_name}PAE
%defattr(744,root,root,-)
/lib/modules/%{kernel}PAE/%{kernel_module_dir}
%endif


%changelog
* Mon Nov 12 2007 Urs Beyerle <urs.beyerle@psi.ch> - 0.4-1
- initial source taken from centos 5 extra repo
- initial build for SL5
